@@ -17,16 +17,16 @@ import hashlib
 import json
 import os
 import shutil
+import sup_process
 import time
 import unittest
 
-from slapos.runner.utils import (getProfilePath, getRcode,
+from slapos.runner.utils import (getProfilePath,
                                  getSession, isInstanceRunning,
                                  isSoftwareRunning, startProxy,
                                  isSoftwareReleaseReady,
-                                 runSlapgridUntilSuccess,
+                                 runSlapgridUntilSuccess, runInstanceWithLock,
                                  getBuildAndRunParams, saveBuildAndRunParams)
-from slapos.runner.process import killRunningProcess, isRunning
 from slapos.runner import views
 import slapos.slap
 from slapos.htpasswd import  HtpasswdFile
@@ -137,9 +137,9 @@ class SlaprunnerTestCase(unittest.TestCase):
     if os.path.exists(self.app.config['software_link']):
       shutil.rmtree(self.app.config['software_link'])
     #Stop process
-    killRunningProcess('slapproxy', recursive=True)
-    killRunningProcess('slapgrid-cp', recursive=True)
-    killRunningProcess('slapgrid-sr', recursive=True)
+    sup_process.killRunningProcess(self.app.config, 'slapproxy')
+    sup_process.killRunningProcess(self.app.config, 'slapgrid-cp')
+    sup_process.killRunningProcess(self.app.config, 'slapgrid-sr')
 
   def updateConfigParameter(self, parameter, value):
     config_parser = ConfigParser.SafeConfigParser()
@@ -186,10 +186,10 @@ class SlaprunnerTestCase(unittest.TestCase):
 
   def proxyStatus(self, status=True, sleep_time=0):
     """Helper for testslapproxy status"""
-    proxy = isRunning('slapproxy')
+    proxy = sup_process.isRunning(self.app.config, 'slapproxy')
     if proxy != status and sleep_time != 0:
       time.sleep(sleep_time)
-      proxy = isRunning('slapproxy')
+      proxy = sup_process.isRunning(self.app.config, 'slapproxy')
     self.assertEqual(proxy, status)
 
   def setupProjectFolder(self, withSoftware=False):
@@ -232,7 +232,7 @@ class SlaprunnerTestCase(unittest.TestCase):
 
   def stopSlapproxy(self):
     """Kill slapproxy process"""
-    killRunningProcess('slapproxy', recursive=True)
+    pass
 
   def test_configAccount(self):
     """For the first lauch of slaprunner user need do create first account"""
@@ -256,12 +256,8 @@ class SlaprunnerTestCase(unittest.TestCase):
 
   def test_startStopProxy(self):
     """Test slapproxy"""
-    self.stopSlapproxy()
-    self.proxyStatus(False)
     startProxy(self.app.config)
     self.proxyStatus(True)
-    self.stopSlapproxy()
-    self.proxyStatus(False, sleep_time=1)
 
   def test_cloneProject(self):
     """Start scenario 1 for deploying SR: Clone a project from git repository"""
@@ -408,7 +404,6 @@ class SlaprunnerTestCase(unittest.TestCase):
   def test_requestInstance(self):
     """Scenarion 6: request software instance"""
     self.test_updateInstanceParameter()
-    self.proxyStatus(False, sleep_time=1)
     #run Software profile
     response = loadJson(self.app.post('/runSoftwareProfile',
                                       data=dict(),
@@ -459,7 +454,7 @@ class SlaprunnerTestCase(unittest.TestCase):
     self.assertEqual(response, "2")
     # Test that the new call to isSoftwareReleaseReady
     # doesn't overwrite the previous installed one
-    killRunningProcess('slapgrid-sr')
+    sup_process.killRunningProcess(self.app.config, 'slapgrid-sr')
     completed_path = os.path.join(self.app.config['runner_workdir'],
         'softwareLink', 'slaprunner-test', '.completed')
     completed_text = ".completed file: test"
@@ -532,13 +527,59 @@ class SlaprunnerTestCase(unittest.TestCase):
     response = runSlapgridUntilSuccess(self.app.config, 'software')
     self.assertEqual(response, (1, MAX_RUN_INSTANCE))
 
+  def test_slaveInstanceDeployment(self):
+    """
+    In order to test both slapproxy and core features of
+    slaprunner, will install special Software Release
+    into the current webrunner and fetch its instance
+    parameters once deployed.
+    """
+    # XXX: This test should NOT be a unit test but should be run
+    # by a Test Agent running against a slapproxy.
+
+    # Deploy "test-slave-instance-deployment" Software Release
+    self.test_cloneProject()
+    software = os.path.join(self.software, 'test-slave-instance-deployment')
+
+    # Checkout to master branch
+    response = loadJson(self.app.post('/newBranch',
+                                      data=dict(
+                                        project=self.software,
+                                        create='0',
+                                        name='master'
+                                      ),
+                                      follow_redirects=True)).get(u'code')
+    self.assertEqual(response, 1)
+    response = loadJson(self.app.post('/setCurrentProject',
+                                      data=dict(path=software),
+                                      follow_redirects=True)).get(u'code')
+    self.assertEqual(response, 1)
+
+    response = loadJson(self.app.post('/saveParameterXml',
+                                      data=dict(parameter='<?xml version="1.0" encoding="utf-8"?>\n<instance/>',
+                                                software_type='default'),
+                                      follow_redirects=True))
+
+    while self.app.get('/isSRReady').data == "2":
+      time.sleep(2)
+    self.assertEqual(self.app.get('/isSRReady').data, "1")
+
+    # Run instance deployment 3 times
+    runInstanceWithLock(self.app.config)
+    runInstanceWithLock(self.app.config)
+    result = runInstanceWithLock(self.app.config)
+    # result is True if returncode is 0 (i.e "deployed and promise passed")
+    self.assertTrue(result)
+
+    self.proxyStatus(True)
+    self.stopSlapproxy()
 
   def test_dynamicParametersReading(self):
     """Test if the value of a parameter can change in the flask application
     only by changing the value of slapos.cfg config file. This can happen when
     slapgrid processes the webrunner's partition.
     """
-    config_file = os.path.join(self.app.config['etc_dir'], 'slapos.cfg')
+    config_file = os.path.join(self.app.config['etc_dir'], 'slapos-test.cfg')
     runner_config_old = os.environ['RUNNER_CONFIG']
     os.environ['RUNNER_CONFIG'] = config_file
     open(config_file, 'w').write("[section]\nvar=value")
